@@ -9,6 +9,7 @@ use tauri_utils::acl::capability::{Capability, PermissionEntry};
 
 use crate::{
   acl::FileFormat,
+  error::ErrorExt,
   helpers::{app_paths::tauri_dir, prompts},
   Result,
 };
@@ -106,7 +107,9 @@ pub fn command(options: Options) -> Result<()> {
   };
 
   let path = match options.out {
-    Some(o) => o.canonicalize()?,
+    Some(o) => o
+      .canonicalize()
+      .fs_context("failed to canonicalize capability file path", o.clone())?,
     None => {
       let dir = tauri_dir();
       let capabilities_dir = dir.join("capabilities");
@@ -125,17 +128,21 @@ pub fn command(options: Options) -> Result<()> {
     );
     let overwrite = prompts::confirm(&format!("{msg}, overwrite?"), Some(false))?;
     if overwrite {
-      std::fs::remove_file(&path)?;
+      std::fs::remove_file(&path).fs_context("failed to remove capability file", path.clone())?;
     } else {
-      anyhow::bail!(msg);
+      crate::error::bail!(msg);
     }
   }
 
   if let Some(parent) = path.parent() {
-    std::fs::create_dir_all(parent)?;
+    std::fs::create_dir_all(parent).fs_context(
+      "failed to create capability directory",
+      parent.to_path_buf(),
+    )?;
   }
 
-  std::fs::write(&path, options.format.serialize(&capability)?)?;
+  std::fs::write(&path, options.format.serialize(&capability)?)
+    .fs_context("failed to write capability file", path.clone())?;
 
   log::info!(action = "Created"; "capability at {}", dunce::simplified(&path).display());
 
