@@ -8,7 +8,6 @@ use std::{
   process::{Command, ExitStatus},
 };
 
-use anyhow::{Context, Result};
 use serde::Deserialize;
 
 pub mod certificate;
@@ -18,6 +17,61 @@ mod provisioning_profile;
 pub use keychain::{Keychain, Team};
 pub use provisioning_profile::ProvisioningProfile;
 
+#[derive(Debug, thiserror::Error)]
+pub enum Error {
+  #[error("failed to create temp directory: {0}")]
+  TempDir(std::io::Error),
+  #[error("failed to resolve home dir")]
+  ResolveHomeDir,
+  #[error("failed to resolve signing identity")]
+  ResolveSigningIdentity,
+  #[error("failed to decode provisioning profile")]
+  FailedToDecodeProvisioningProfile,
+  #[error("could not find provisioning profile UUID")]
+  FailedToFindProvisioningProfileUuid,
+  #[error("{context} {path}: {error}")]
+  Plist {
+    context: &'static str,
+    path: PathBuf,
+    error: plist::Error,
+  },
+  #[error("failed to upload app to Apple's notarization servers: {error}")]
+  FailedToUploadApp { error: std::io::Error },
+  #[error("failed to notarize app: {0}")]
+  Notarize(String),
+  #[error("failed to parse notarytool output as JSON: {output}")]
+  ParseNotarytoolOutput { output: String },
+  #[error("failed to run command {command}: {error}")]
+  CommandFailed {
+    command: String,
+    error: std::io::Error,
+  },
+  #[error("{context} {path}: {error}")]
+  Fs {
+    context: &'static str,
+    path: PathBuf,
+    error: std::io::Error,
+  },
+  #[error("failed to parse X509 certificate: {error}")]
+  X509Certificate {
+    error: x509_certificate::X509CertificateError,
+  },
+  #[error("failed to create PFX from self signed certificate")]
+  FailedToCreatePFX,
+  #[error("failed to create self signed certificate: {error}")]
+  FailedToCreateSelfSignedCertificate {
+    error: Box<apple_codesign::AppleCodesignError>,
+  },
+  #[error("failed to encode DER: {error}")]
+  FailedToEncodeDER { error: std::io::Error },
+  #[error("certificate missing common name")]
+  CertificateMissingCommonName,
+  #[error("certificate missing organization unit for common name {common_name}")]
+  CertificateMissingOrganizationUnit { common_name: String },
+}
+
+pub type Result<T> = std::result::Result<T, Error>;
+
 trait CommandExt {
   // The `pipe` function sets the stdout and stderr to properly
   // show the command output in the Node.js wrapper.
@@ -88,7 +142,7 @@ fn notarize_inner(
     .file_stem()
     .expect("failed to get bundle filename");
 
-  let tmp_dir = tempfile::tempdir()?;
+  let tmp_dir = tempfile::tempdir().map_err(Error::TempDir)?;
   let zip_path = tmp_dir
     .path()
     .join(format!("{}.zip", bundle_stem.to_string_lossy()));
@@ -110,7 +164,11 @@ fn notarize_inner(
   assert_command(
     Command::new("ditto").args(zip_args).piped(),
     "failed to zip app with ditto",
-  )?;
+  )
+  .map_err(|error| Error::CommandFailed {
+    command: "ditto".to_string(),
+    error,
+  })?;
 
   // sign the zip file
   keychain.sign(&zip_path, None, false)?;
@@ -135,13 +193,12 @@ fn notarize_inner(
     .args(notarize_args)
     .notarytool_args(auth, tmp_dir.path())?
     .output()
-    .context("failed to upload app to Apple's notarization servers.")?;
+    .map_err(|error| Error::FailedToUploadApp { error })?;
 
   if !output.status.success() {
-    return Err(
-      anyhow::anyhow!("failed to notarize app")
-        .context(String::from_utf8_lossy(&output.stderr).into_owned()),
-    );
+    return Err(Error::Notarize(
+      String::from_utf8_lossy(&output.stderr).into_owned(),
+    ));
   }
 
   let output_str = String::from_utf8_lossy(&output.stdout);
@@ -176,17 +233,17 @@ fn notarize_inner(
       .notarytool_args(auth, tmp_dir.path())?
       .output()
     {
-      Err(anyhow::anyhow!(
+      Err(Error::Notarize(format!(
         "{log_message}\nLog:\n{}",
         String::from_utf8_lossy(&output.stdout)
-      ))
+      )))
     } else {
-      Err(anyhow::anyhow!("{log_message}"))
+      Err(Error::Notarize(log_message.to_string()))
     }
   } else {
-    Err(anyhow::anyhow!(
-      "failed to parse notarytool output as JSON: `{output_str}`"
-    ))
+    Err(Error::ParseNotarytoolOutput {
+      output: output_str.into_owned(),
+    })
   }
 }
 
@@ -204,7 +261,10 @@ fn staple_app(mut app_bundle_path: PathBuf) -> Result<()> {
     .args(vec!["stapler", "staple", "-v", filename])
     .current_dir(app_bundle_path)
     .output()
-    .context("failed to staple app.")?;
+    .map_err(|error| Error::CommandFailed {
+      command: "xcrun stapler staple".to_string(),
+      error,
+    })?;
 
   Ok(())
 }
@@ -245,7 +305,11 @@ impl NotarytoolCmdExt for Command {
         let key_path = match key {
           ApiKey::Raw(k) => {
             let key_path = temp_dir.join("AuthKey.p8");
-            std::fs::write(&key_path, k)?;
+            std::fs::write(&key_path, k).map_err(|error| Error::Fs {
+              context: "failed to write notarization API key to temp file",
+              path: key_path.clone(),
+              error,
+            })?;
             key_path
           }
           ApiKey::Path(p) => p.to_owned(),
@@ -266,7 +330,7 @@ impl NotarytoolCmdExt for Command {
 }
 
 fn decode_base64(base64: &OsStr, out_path: &Path) -> Result<()> {
-  let tmp_dir = tempfile::tempdir()?;
+  let tmp_dir = tempfile::tempdir().map_err(Error::TempDir)?;
 
   let src_path = tmp_dir.path().join("src");
   let base64 = base64
@@ -277,7 +341,11 @@ fn decode_base64(base64: &OsStr, out_path: &Path) -> Result<()> {
   // as base64 contain whitespace decoding may be broken
   // https://github.com/marshallpierce/rust-base64/issues/105
   // we'll use builtin base64 command from the OS
-  std::fs::write(&src_path, base64)?;
+  std::fs::write(&src_path, base64).map_err(|error| Error::Fs {
+    context: "failed to write base64 to temp file",
+    path: src_path.clone(),
+    error,
+  })?;
 
   assert_command(
     std::process::Command::new("base64")
@@ -288,13 +356,17 @@ fn decode_base64(base64: &OsStr, out_path: &Path) -> Result<()> {
       .arg(out_path)
       .piped(),
     "failed to decode certificate",
-  )?;
+  )
+  .map_err(|error| Error::CommandFailed {
+    command: "base64 --decode".to_string(),
+    error,
+  })?;
 
   Ok(())
 }
 
 fn assert_command(
-  response: Result<std::process::ExitStatus, std::io::Error>,
+  response: std::result::Result<std::process::ExitStatus, std::io::Error>,
   error_message: &str,
 ) -> std::io::Result<()> {
   let status =
