@@ -126,6 +126,7 @@ pub enum Error {
   /// Failed to create webview.
   #[error("failed to create webview: {0}")]
   CreateWebview(Box<dyn std::error::Error + Send + Sync>),
+  // TODO: Make it take an error like `CreateWebview` in v3
   /// Failed to create window.
   #[error("failed to create window")]
   CreateWindow,
@@ -297,7 +298,9 @@ pub trait RuntimeHandle<T: UserEvent>: Debug + Clone + Send + Sync + Sized + 'st
   fn run_on_main_thread<F: FnOnce() + Send + 'static>(&self, f: F) -> Result<()>;
 
   /// Get a handle to the display controller of the windowing system.
-  fn display_handle(&self) -> std::result::Result<DisplayHandle, raw_window_handle::HandleError>;
+  fn display_handle(
+    &self,
+  ) -> std::result::Result<DisplayHandle<'_>, raw_window_handle::HandleError>;
 
   /// Returns the primary monitor of the system.
   ///
@@ -326,6 +329,15 @@ pub trait RuntimeHandle<T: UserEvent>: Debug + Clone + Send + Sync + Sized + 'st
   #[cfg_attr(docsrs, doc(cfg(target_os = "macos")))]
   fn hide(&self) -> Result<()>;
 
+  /// Change the device event filter mode.
+  ///
+  /// See [Runtime::set_device_event_filter] for details.
+  ///
+  /// ## Platform-specific
+  ///
+  /// See [Runtime::set_device_event_filter] for details.
+  fn set_device_event_filter(&self, filter: DeviceEventFilter);
+
   /// Finds an Android class in the project scope.
   #[cfg(target_os = "android")]
   fn find_class<'a>(
@@ -559,8 +571,7 @@ pub trait WebviewDispatch<T: UserEvent>: Debug + Clone + Send + Sync + Sized + '
   ///
   /// # Stability
   ///
-  /// The return value of this function leverages [`cookie::Cookie`] which re-exports the cookie crate.
-  /// This dependency might receive updates in minor Tauri releases.
+  /// See [WebviewDispatch::cookies].
   fn cookies_for_url(&self, url: Url) -> Result<Vec<Cookie<'static>>>;
 
   /// Return all cookies in the cookie store.
@@ -571,6 +582,20 @@ pub trait WebviewDispatch<T: UserEvent>: Debug + Clone + Send + Sync + Sized + '
   /// This dependency might receive updates in minor Tauri releases.
   fn cookies(&self) -> Result<Vec<Cookie<'static>>>;
 
+  /// Set a cookie for the webview.
+  ///
+  /// # Stability
+  ///
+  /// See [WebviewDispatch::cookies].
+  fn set_cookie(&self, cookie: cookie::Cookie<'_>) -> Result<()>;
+
+  /// Delete a cookie for the webview.
+  ///
+  /// # Stability
+  ///
+  /// See [WebviewDispatch::cookies].
+  fn delete_cookie(&self, cookie: cookie::Cookie<'_>) -> Result<()>;
+
   /// Sets whether the webview should automatically grow and shrink its size and position when the parent window resizes.
   fn set_auto_resize(&self, auto_resize: bool) -> Result<()>;
 
@@ -841,9 +866,15 @@ pub trait WindowDispatch<T: UserEvent>: Debug + Clone + Send + Sync + Sized + 's
   /// Updates the window fullscreen state.
   fn set_fullscreen(&self, fullscreen: bool) -> Result<()>;
 
+  #[cfg(target_os = "macos")]
+  fn set_simple_fullscreen(&self, enable: bool) -> Result<()>;
+
   /// Bring the window to front and focus.
   fn set_focus(&self) -> Result<()>;
 
+  /// Sets whether the window can be focused.
+  fn set_focusable(&self, focusable: bool) -> Result<()>;
+
   /// Updates the window icon.
   fn set_icon(&self, icon: Icon) -> Result<()>;
 
