@@ -5,6 +5,7 @@
 package app.tauri.plugin
 
 import android.app.PendingIntent
+import android.content.res.Configuration
 import android.content.Context
 import android.content.Intent
 import android.webkit.WebView
@@ -17,6 +18,8 @@ import app.tauri.annotation.InvokeArg
 import app.tauri.FsUtils
 import app.tauri.JniMethod
 import app.tauri.Logger
+import com.fasterxml.jackson.annotation.JsonAutoDetect
+import com.fasterxml.jackson.annotation.PropertyAccessor
 import com.fasterxml.jackson.databind.DeserializationFeature
 import com.fasterxml.jackson.databind.JsonNode
 import com.fasterxml.jackson.databind.ObjectMapper
@@ -69,6 +72,7 @@ class PluginManager(val activity: AppCompatActivity) {
     jsonMapper = ObjectMapper()
       .disable(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES)
       .enable(DeserializationFeature.FAIL_ON_NULL_FOR_PRIMITIVES)
+      .setVisibility(PropertyAccessor.FIELD, JsonAutoDetect.Visibility.ANY)
 
     val channelDeserializer = ChannelDeserializer({ channelId, payload ->
       sendChannelData(channelId, payload)
@@ -95,6 +99,30 @@ class PluginManager(val activity: AppCompatActivity) {
     }
   }
 
+  fun onRestart() {
+    for (plugin in plugins.values) {
+      plugin.instance.onRestart()
+    }
+  }
+
+  fun onStop() {
+    for (plugin in plugins.values) {
+      plugin.instance.onStop()
+    }
+  }
+
+  fun onDestroy() {
+    for (plugin in plugins.values) {
+      plugin.instance.onDestroy()
+    }
+  }
+
+  fun onConfigurationChanged(newConfig: Configuration) {
+    for (plugin in plugins.values) {
+      plugin.instance.onConfigurationChanged(newConfig)
+    }
+  }
+
   fun startActivityForResult(intent: Intent, callback: ActivityResultCallback) {
     startActivityForResultCallback = callback
     startActivityForResultLauncher.launch(intent)
