@@ -91,19 +91,20 @@ pub fn format<T: Serialize>(function_name: CallbackFn, arg: &T) -> crate::Result
 /// than 10 KiB with `JSON.parse('...')`.
 /// See [json-parse-benchmark](https://github.com/GoogleChromeLabs/json-parse-benchmark).
 pub fn format_raw(function_name: CallbackFn, json_string: String) -> crate::Result<String> {
+  let callback_id = function_name.0;
   serialize_js_with(json_string, Default::default(), |arg| {
-    format!(
-      r#"
-    if (window["_{fn}"]) {{
-      window["_{fn}"]({arg})
-    }} else {{
-      console.warn("[TAURI] Couldn't find callback id {fn} in window. This happens when the app is reloaded while Rust is running an asynchronous operation.")
-    }}"#,
-      fn = function_name.0
-    )
+    format_raw_js(callback_id, arg)
   })
 }
 
+/// Formats a function name and a JavaScript string argument to be evaluated as callback.
+pub fn format_raw_js(callback_id: u32, js: impl AsRef<str>) -> String {
+  fn format_inner(callback_id: u32, js: &str) -> String {
+    format!("window.__TAURI_INTERNALS__.runCallback({callback_id}, {js})")
+  }
+  format_inner(callback_id, js.as_ref())
+}
+
 /// Formats a serializable Result type to its Promise response.
 ///
 /// See [`format_result_raw`] for more information.
@@ -232,11 +233,11 @@ mod test {
     // call format callback
     let fc = format(f, &a).unwrap();
     fc.contains(&format!(
-      r#"window["_{}"](JSON.parse('{}'))"#,
+      "window.__TAURI_INTERNALS__.runCallback({}, JSON.parse('{}'))",
       f.0,
       serde_json::Value::String(a.clone()),
     )) || fc.contains(&format!(
-      r#"window["_{}"]({})"#,
+      r#"window.__TAURI_INTERNALS__.runCallback({}, {})"#,
       f.0,
       serde_json::Value::String(a),
     ))
@@ -252,7 +253,7 @@ mod test {
     };
 
     resp.contains(&format!(
-      r#"window["_{}"]({})"#,
+      r#"window.__TAURI_INTERNALS__.runCallback({}, {})"#,
       function.0,
       serde_json::Value::String(value),
     ))
@@ -316,8 +317,13 @@ mod test {
     let a = a.0;
     // call format callback
     let fc = format_raw(f, a.clone()).unwrap();
-    fc.contains(&format!(r#"window["_{}"](JSON.parse('{}'))"#, f.0, a))
-      || fc.contains(&format!(r#"window["_{}"]({})"#, f.0, a))
+    fc.contains(&format!(
+      r#"window.__TAURI_INTERNALS__.runCallback({}, JSON.parse('{}'))"#,
+      f.0, a
+    )) || fc.contains(&format!(
+      r#"window.__TAURI_INTERNALS__.runCallback({}, {})"#,
+      f.0, a
+    ))
   }
 
   // check arbitrary strings in format_result
@@ -330,6 +336,9 @@ mod test {
       Err(e) => (ec, e),
     };
 
-    resp.contains(&format!(r#"window["_{}"]({})"#, function.0, value))
+    resp.contains(&format!(
+      r#"window.__TAURI_INTERNALS__.runCallback({}, {})"#,
+      function.0, value
+    ))
   }
 }
