@@ -265,7 +265,7 @@ impl<R: Runtime> AppManager<R> {
       crate::app::GlobalTrayIconEventListener<AppHandle<R>>,
     >,
     window_event_listeners: Vec<GlobalWindowEventListener<R>>,
-    webiew_event_listeners: Vec<GlobalWebviewEventListener<R>>,
+    webview_event_listeners: Vec<GlobalWebviewEventListener<R>>,
     #[cfg(desktop)] window_menu_event_listeners: HashMap<
       String,
       crate::app::GlobalMenuEventListener<Window<R>>,
@@ -292,7 +292,7 @@ impl<R: Runtime> AppManager<R> {
         invoke_handler,
         on_page_load,
         uri_scheme_protocols: Mutex::new(uri_scheme_protocols),
-        event_listeners: Arc::new(webiew_event_listeners),
+        event_listeners: Arc::new(webview_event_listeners),
         invoke_initialization_script,
         invoke_key: invoke_key.clone(),
       },
